pub fn test_scope(filter: LevelFilter, enclosed_function: fn())Expand description
A trace helper used in the examples that scopes the trace to the provided closure
pub fn test_scope(filter: LevelFilter, enclosed_function: fn())A trace helper used in the examples that scopes the trace to the provided closure